@@ -11,34 +11,39 @@ __title__: str = "RPD"
 __author__: str = "VincentRPS"
 __license__: str = "MIT"
 __copyright__: str = "Copyright 2021-present VincentRPS"
-__version__: str = "0.3.0"
+__version__: str = "0.4.0"
 
 import logging
 import typing
 
+# there are a lot of
+# problems with importing rpd.apps for some reason.
 from rpd.api import *
 from rpd.apps import *
-from rpd.boot_text import *
 from rpd.color import *
 from rpd.colour import *
+from rpd.events import *
 from rpd.intents import *
 from rpd.internal.exceptions import *
 from rpd.internal.warnings import *
+from rpd.message import *
 from rpd.snowflake import *
+from rpd.traits import *
+from rpd.ui import *
 from rpd.util import *
 from rpd.webhooks import *
 
 
 class VersionInfo(typing.NamedTuple):
-    major: int
-    minor: int
-    micro: int
+    major: str
+    minor: str
+    micro: str
     releaselevel: typing.Literal["alpha", "beta", "candidate", "final"]
     serial: int
 
 
 version_info: VersionInfo = VersionInfo(
-    major=0, minor=3, micro=0, releaselevel="final", serial=0
+    major=0, minor=4, micro=0, releaselevel="final", serial=0
 )
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
